@@ -118,7 +118,7 @@ class OracleDao(object):
         :param db_conn: 数据库连接字符串，例如："192.168.1.110:1521/testdb"
         :param encoding: 编码，默认为utf-8
         """
-        self.conn = cx_Oracle.connect(db_name, db_pwd, db_conn, encoding)
+        self.conn = cx_Oracle.connect(db_name, db_pwd, db_conn, encoding=encoding)
         self.cur = self.conn.cursor()
 
     def __enter__(self):
