@@ -79,7 +79,7 @@ class Log():
         if file_handler:
             if len(self.logger.handlers) <= 1:  # 如果小于等于1个日志器，表明没有添加过文件日志器
                 if self.logger_name:
-                    log_file = os.path.join(log_dir, self.logger_name, '.log')
+                    log_file = os.path.join(log_dir, f'{self.logger_name}.log')
                 else:
                     log_file = os.path.join(log_dir, 'chb.log')
                 file_handler = logging.FileHandler(log_file, encoding='UTF-8')
